@@ -24,7 +24,7 @@ const matrixConfig = [
     manager: "cargo",
     install_cmd: "",
     run_cmd: "cargo",
-    templates: ["vanilla", "yew", "sycamore", "leptos"],
+    templates: ["vanilla", "yew", "sycamore", "leptos", "dioxus"],
   },
   {
     manager: "pnpm",
@@ -78,16 +78,17 @@ matrixConfig
         const jobInfo = {
           template: t,
           install_trunk: ["yew", "sycamore", "leptos"].includes(t),
-          rc: false,
-          no_bundle_flag: "-b none",
+          install_dioxus_cli: t === "dioxus",
+          tauriVersion: "latest",
+          no_bundle_flag: "--no-bundle",
           ...managerInfo,
         };
         outMatrix.push(jobInfo);
         outMatrix.push({
           ...jobInfo,
-          rc: true,
-          no_bundle_flag: "--no-bundle",
-          flags: "--rc",
+          tauriVersion: 1,
+          no_bundle_flag: "-b none",
+          flags: "--tauri-version 1",
         });
       }
     }
